/* Copyright 2016 Diego Islas Ocampo
*
* This file is part of Kirino.
*
* Kirino is free software: you can redistribute it
* and/or modify it under the terms of the GNU General Public License as
* published by the Free Software Foundation, either version 3 of the
* License, or (at your option) any later version.
*
* Kirino is distributed in the hope that it will be
* useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General
* Public License for more details.
*
* You should have received a copy of the GNU General Public License along
* with Kirino. If not, see http://www.gnu.org/licenses/.
*/

class Text {

    private const Correction[] typos = {
        {" ABBOUT ", " ABOUT "},
        {" ABOTU ", " ABOUT "},
        {" ABOUTA ", " ABOUT A "},
        {" ABOUTIT ", " ABOUT IT "},
        {" ABOUTTHE ", " ABOUT THE "},
        {" ABSCENSE ", " ABSENCE "},
        {" ACCESORIES ", " ACCESSORIES "},
        {" ACCIDANT ", " ACCIDENT "},
        {" ACCOMODATE ", " ACCOMMODATE "},
        {" ACCORDINGTO ", " ACCORDING TO "},
        {" ACCROSS ", " ACROSS "},
        {" ACHEIVE ", " ACHIEVE "},
        {" ACHEIVED ", " ACHIEVED "},
        {" ACHEIVING ", " ACHIEVING "},
        {" ACN ", " CAN "},
        {" ACOMMODATE ", " ACCOMMODATE "},
        {" ACOMODATE ", " ACCOMMODATE "},
        {" ACTUALYL ", " ACTUALLY "},
        {" ADDITIINAL ", " ADDITIONAL "},
        {" ADDTIONAL ", " ADDITIONAL "},
        {" ADEQUIT ", " ADEQUATE "},
        {" ADEQUITE ", " ADEQUATE "},
        {" ADVANAGE ", " ADVANTAGE "},
        {" AFFRAID ", " AFRAID "},
        {" AFTERTHE ", " AFTER THE "},
        {" AGAINSTT HE ", " AGAINST THE "},
        {" AGANIST ", " AGAINST "},
        {" AGGRESIVE ", " AGGRESSIVE "},
        {" AGIAN ", " AGAIN "},
        {" AGREEMEENT ", " AGREEMENT "},
        {" AGREEMEENTS ", " AGREEMENTS "},
        {" AGREEMNET ", " AGREEMENT "},
        {" AGREEMNETS ", " AGREEMENTS "},
        {" AGRESSIVE ", " AGGRESSIVE "},
        {" AHPPEN ", " HAPPEN "},
        {" AHVE ", " HAVE "},
        {" ALLWASY ", " ALWAYS "},
        {" ALLWYAS ", " ALWAYS "},
        {" ALMOTS ", " ALMOST "},
        {" ALMSOT ", " ALMOST "},
        {" ALOMST ", " ALMOST "},
        {" ALOT ", " A LOT "},
        {" ALRAEDY ", " ALREADY "},
        {" ALREAYD ", " ALREADY "},
        {" ALREDAY ", " ALREADY "},
        {" ALWASY ", " ALWAYS "},
        {" ALWATS ", " ALWAYS "},
        {" ALWAY ", " ALWAYS "},
        {" ALWYAS ", " ALWAYS "},
        {" AMDE ", " MADE "},
        {" AMERIA ", " AMERICA "},
        {" AMKE ", " MAKE "},
        {" AMKES ", " MAKES "},
        {" ANBD ", " AND "},
        {" ANDONE ", " AND ONE "},
        {" ANDT HE ", " AND THE "},
        {" ANDTEH ", " AND THE "},
        {" ANDTHE ", " AND THE "},
        {" ANOTHE ", " ANOTHER "},
        {" ANUAL ", " ANNUAL "},
        {" APPARANT ", " APPARENT "},
        {" APPARRENT ", " APPARENT "},
        {" APPEARENCE ", " APPEARANCE "},
        {" APPEARES ", " APPEARS "},
        {" APPLICAITON ", " APPLICATION "},
        {" APPLICAITONS ", " APPLICATIONS "},
        {" APPLYED ", " APPLIED "},
        {" APPOINTIMENT ", " APPOINTMENT "},
        {" APPRORPIATE ", " APPROPRIATE "},
        {" APPRORPRIATE ", " APPROPRIATE "},
        {" AQUISITION ", " ACQUISITION "},
        {" AQUISITIONS ", " ACQUISITIONS "},
        {" AREN;T ", " AREN'T "},
        {" ARGUEMENT ", " ARGUMENT "},
        {" ARGUEMENTS ", " ARGUMENTS "},
        {" ARN'T ", " AREN'T "},
        {" AROND ", " AROUND "},
        {" ARTICAL ", " ARTICLE "},
        {" ARTICEL ", " ARTICLE "},
        {" ASDVERTISING ", " ADVERTISING "},
        {" ASKT HE ", " ASK THE "},
        {" ASSISTENT ", " ASSISTANT "},
        {" ASTHE ", " AS THE "},
        {" ATENTION ", " ATTENTION "},
        {" ATMOSPHER ", " ATMOSPHERE "},
        {" ATTENTIOIN ", " ATTENTION "},
        {" ATTHE ", " AT THE "},
        {" AUDEINCE ", " AUDIENCE "},
        {" AUDIANCE ", " AUDIENCE "},
        {" AVAILALBE ", " AVAILABLE "},
        {" AWYA ", " AWAY "},
        {" AYWA ", " AWAY "},
        {" BAKC ", " BACK "},
        {" BALENCE ", " BALANCE "},
        {" BALLANCE ", " BALANCE "},
        {" BAOUT ", " ABOUT "},
        {" BCAK ", " BACK "},
        {" BEACUSE ", " BECAUSE "},
        {" BECASUE ", " BECAUSE "},
        {" BECAUS ", " BECAUSE "},
        {" BECAUSEA ", " BECAUSE A "},
        {" BECAUSEOF ", " BECAUSE OF "},
        {" BECAUSETHE ", " BECAUSE THE "},
        {" BECAUSEYOU ", " BECAUSE YOU "},
        {" BECOMEING ", " BECOMING "},
        {" BECOMMING ", " BECOMING "},
        {" BECUASE ", " BECAUSE "},
        {" BECUSE ", " BECAUSE "},
        {" BEFOER ", " BEFORE "},
        {" BEGGINING ", " BEGINNING "},
        {" BEGINING ", " BEGINNING "},
        {" BEGININING ", " BEGINNING "},
        {" BELEIEV ", " BELIEVE "},
        {" BELEIEVE ", " BELIVE "},
        {" BELEIF ", " BELIEF "},
        {" BELEIVE ", " BELIEVE "},
        {" BELEIVED ", " BELIEVED "},
        {" BELEIVES ", " BELIEVES "},
        {" BENIFIT ", " BENEFIT "},
        {" BENIFITS ", " BENEFITS "},
        {" BETWEN ", " BETWEEN "},
        {" BEUTIFUL ", " BEAUTIFUL "},
        {" BLASE ", " BLASÉ "},
        {" BOXS ", " BOXES "},
        {" BRODCAST ", " BROADCAST "},
        {" BUTTHE ", " BUT THE "},
        {" BVE ", " BE "},
        {" BYT HE ", " BY THE "},
        {" CAFE ", " CAFÉ "},
        {" CAHARCTER ", " CHARACTER "},
        {" CALCULLATED ", " CALCULATED "},
        {" CALULATED ", " CALCULATED "},
        {" CAN;T ", " CAN'T "},
        {" CAN'T OF BEEN ", " CAN'T HAVE BEEN "},
        {" CANDIDTAE ", " CANDIDATE "},
        {" CANDIDTAES ", " CANDIDATES "},
        {" CATAGORY ", " CATEGORY "},
        {" CATEGIORY ", " CATEGORY "},
        {" CERTIAN ", " CERTAIN "},
        {" CHALLANGE ", " CHALLENGE "},
        {" CHALLANGES ", " CHALLENGES "},
        {" CHANEG ", " CHANGE "},
        {" CHANEGS ", " CHANGES "},
        {" CHANGABLE ", " CHANGEABLE "},
        {" CHANGEING ", " CHANGING "},
        {" CHANGNG ", " CHANGING "},
        {" CHARACHTER ", " CHARACTER "},
        {" CHARACHTERS ", " CHARACTERS "},
        {" CHARACTOR ", " CHARACTER "},
        {" CHARECTER ", " CHARACTER "},
        {" CHARECTOR ", " CHARACTER "},
        {" CHEIF ", " CHIEF "},
        {" CHEKC ", " CHECK "},
        {" CHNAGE ", " CHANGE "},
        {" CIELING ", " CEILING "},
        {" CIRCUT ", " CIRCUIT "},
        {" CLAER ", " CLEAR "},
        {" CLAERED ", " CLEARED "},
        {" CLAERLY ", " CLEARLY "},
        {" CLIANT ", " CLIENT "},
        {" COLECTION ", " COLLECTION "},
        {" COMANIES ", " COMPANIES "},
        {" COMANY ", " COMPANY "},
        {" COMAPNIES ", " COMPANIES "},
        {" COMAPNY ", " COMPANY "},
        {" COMBINTATION ", " COMBINATION "},
        {" COMITED ", " COMMITTED "},
        {" COMITTEE ", " COMMITTEE "},
        {" COMMADN ", " COMMAND "},
        {" COMMING ", " COMING "},
        {" COMMITEE ", " COMMITTEE "},
        {" COMMITTE ", " COMMITTEE "},
        {" COMMITTMENT ", " COMMITMENT "},
        {" COMMITTMENTS ", " COMMITMENTS "},
        {" COMMITTY ", " COMMITTEE "},
        {" COMNTAIN ", " CONTAIN "},
        {" COMNTAINS ", " CONTAINS "},
        {" COMPAIR ", " COMPARE "},
        {" COMPANY;S ", " COMPANY'S "},
        {" COMPLEATED ", " COMPLETED "},
        {" COMPLEATLY ", " COMPLETELY "},
        {" COMPLEATNESS ", " COMPLETENESS "},
        {" COMPLETLY ", " COMPLETELY "},
        {" COMPLETNESS ", " COMPLETENESS "},
        {" COMPOSATE ", " COMPOSITE "},
        {" COMTAIN ", " CONTAIN "},
        {" COMTAINS ", " CONTAINS "},
        {" COMUNICATE ", " COMMUNICATE "},
        {" COMUNITY ", " COMMUNITY "},
        {" CONDOLANCES ", " CONDOLENCES "},
        {" CONECTED ", " CONNECTED "},
        {" CONFERANCE ", " CONFERENCE "},
        {" CONFIRMMATION ", " CONFIRMATION "},
        {" CONSIDERIT ", " CONSIDERATE "},
        {" CONSIDERITE ", " CONSIDERATE "},
        {" CONSONENT ", " CONSONANT "},
        {" CONSPIRICY ", " CONSPIRACY "},
        {" CONSULTENT ", " CONSULTANT "},
        {" CONVERTABLE ", " CONVERTIBLE "},
        {" COOPARATE ", " COOPERATE "},
        {" COOPORATE ", " COOPERATE "},
        {" CORPROATION ", " CORPORATION "},
        {" CORPROATIONS ", " CORPORATIONS "},
        {" CORRUPTABLE ", " CORRUPTIBLE "},
        {" COTTEN ", " COTTON "},
        {" COUDL ", " COULD "},
        {" COUDLN'T ", " COULDN'T "},
        {" COUDLNT ", " COULDN'T "},
        {" COUDNT ", " COULDN'T "},
        {" COUDN'T ", " COULDN'T "},
        {" COULD OF BEEN ", " COULD HAVE BEEN "},
        {" COULD OF HAD ", " COULD HAVE HAD "},
        {" COULDN;T ", " COULDN'T "},
        {" COULDNT ", " COULDN'T "},
        {" COULDTHE ", " COULD THE "},
        {" CPOY ", " COPY "},
        {" CTAEGORY ", " CATEGORY "},
        {" CUSOTMER ", " CUSTOMER "},
        {" CUSOTMERS ", " CUSTOMERS "},
        {" CUTSOMER ", " CUSTOMER "},
        {" CUTSOMERS ", " CUSTOMERS "},
        {" CXAN ", " CAN "},
        {" DAT ", " THAT "},
        {" DANCEING ", " DANCING "},
        {" DCUMENT ", " DOCUMENT "},
        {" DEATILS ", " DETAILS "},
        {" DECISON ", " DECISION "},
        {" DECISONS ", " DECISIONS "},
        {" DEFENDENT ", " DEFENDANT "},
        {" DEFINATELY ", " DEFINITELY "},
        {" DEJAVU ", " DEJA VU "},
        {" DEPTARTMENT ", " DEPARTMENT "},
        {" DESICION ", " DECISION "},
        {" DESICIONS ", " DECISIONS "},
        {" DESISION ", " DECISION "},
        {" DEVELEOPRS ", " DEVELOPERS "},
        {" DEVELLOP ", " DEVELOP "},
        {" DEVELLOPED ", " DEVELOPED "},
        {" DEVELLOPER ", " DEVELOPER "},
        {" DEVELLOPERS ", " DEVELOPERS "},
        {" DEVELLOPING ", " DEVELOPING "},
        {" DEVELLOPMENT ", " DEVELOPMENT "},
        {" DEVELLOPMENTS ", " DEVELOPMENTS "},
        {" DEVELLOPS ", " DEVELOP "},
        {" DEVELOPE ", " DEVELOP "},
        {" DEVELOPEMENT ", " DEVELOPMENT "},
        {" DEVELOPEMENTS ", " DEVELOPMENTS "},
        {" DEVELOPOR ", " DEVELOPER "},
        {" DEVELOPORS ", " DEVELOPERS "},
        {" DEVELPMENT ", " DEVELOPMENT "},
        {" DIAPLAY ", " DISPLAY "},
        {" DIDINT ", " DIDN'T "},
        {" DIDN;T ", " DIDN'T "},
        {" DIDNOT ", " DID NOT "},
        {" DIDNT ", " DIDN'T "},
        {" DIFEFRENT ", " DIFFERENT "},
        {" DIFERENCES ", " DIFFERENCES "},
        {" DIFFERANCE ", " DIFFERENCE "},
        {" DIFFERANCES ", " DIFFERENCES "},
        {" DIFFERANT ", " DIFFERENT "},
        {" DIFFEREMT ", " DIFFERENT "},
        {" DIFFERNT ", " DIFFERENT "},
        {" DIFFRENT ", " DIFFERENT "},
        {" DIRECTER ", " DIRECTOR "},
        {" DIRECTERS ", " DIRECTORS "},
        {" DIRECTIOSN ", " DIRECTIONS "},
        {" DISATISFIED ", " DISSATISFIED "},
        {" DISCOVERD ", " DISCOVERED "},
        {" DISIGN ", " DESIGN "},
        {" DISPALY ", " DISPLAY "},
        {" DISSONENT ", " DISSONANT "},
        {" DISTRIBUSION ", " DISTRIBUTION "},
        {" DIVSION ", " DIVISION "},
        {" DO'NT ", " DON'T "},
        {" DOCUEMENT ", " DOCUMENT "},
        {" DOCUEMNT ", " DOCUMENT "},
        {" DOCUMETN ", " DOCUMENT "},
        {" DOCUMNET ", " DOCUMENT "},
        {" DOCUMNETS ", " DOCUMENTS "},
        {" DOE SNOT ", " DOES NOT "},
        {" DOENS'T ", " DOESN'T "},
        {" DOESE ", " DOES "},
        {" DOESN;T ", " DOESN'T "},
        {" DOESNT ", "DOESN'T "},
        {" DOIGN ", " DOING "},
        {" DOIMG ", " DOING "},
        {" DOIND ", " DOING "},
        {" DOLLERS ", " DOLLARS "},
        {" DON;T ", " DON'T "},
        {" DON'T NO ", " DON'T KNOW "},
        {" DONT NO ", " DON'T KNOW "},
        {" DONIG ", " DOING "},
        {" DONT ", " DON'T "},
        {" DOSN'T ", " DOESN'T "},
        {" DOSNT ", " DOESN'T "},
        {" DRIVEING ", " DRIVING "},
        {" DRNIK ", " DRINK "},
        {" EFEL ", " FEEL "},
        {" EFFICEINT ", " EFFICIENT "},
        {" EFORT ", " EFFORT "},
        {" EFORTS ", " EFFORTS "},
        {" EHR ", " HER "},
        {" ELIGABLE ", " ELIGIBLE "},
        {" EMBARASS ", " EMBARRASS "},
        {" ENOUGHT ", " ENOUGH "},
        {" EQUIPPMENT ", " EQUIPMENT "},
        {" EQUIVALANT ", " EQUIVALENT "},
        {" ESLE ", " ELSE "},
        {" ESPECALLY ", " ESPECIALLY "},
        {" ESPECIALYL ", " ESPECIALLY "},
        {" ESPESIALLY ", " ESPECIALLY "},
        {" EXCELLANT ", " EXCELLENT "},
        {" EXCELENT ", " EXCELLENT "},
        {" EXCERCISE ", " EXERCISE "},
        {" EXCHAGNE ", " EXCHANGE "},
        {" EXCHAGNES ", " EXCHANGES "},
        {" EXCITMENT ", " EXCITEMENT "},
        {" EXHCANGE ", " EXCHANGE "},
        {" EXHCANGES ", " EXCHANGES "},
        {" EXPERIANCE ", " EXPERIENCE "},
        {" EXPERIENC ", " EXPERIENCE "},
        {" EXPRIENCE ", " EXPERIENCE "},
        {" EXPRIENCED ", " EXPERIENCED "},
        {" EYT ", " YET "},
        {" FAETURE ", " FEATURE "},
        {" FAETURES ", " FEATURES "},
        {" FAMILAIR ", " FAMILIAR "},
        {" FAMILAR ", " FAMILIAR "},
        {" FAMILLIAR ", " FAMILIAR "},
        {" FAMMILLIAR ", " FAMILIAR "},
        {" FEILD ", " FIELD "},
        {" FEILDS ", " FIELDS "},
        {" FIANLLY ", " FINALLY "},
        {" FIDN ", " FIND "},
        {" FINALYL ", " FINALLY "},
        {" FIRENDS ", " FRIENDS "},
        {" FIRTS ", " FIRST "},
        {" FOLLWO ", " FOLLOW "},
        {" FOLLWOING ", " FOLLOWING "},
        {" FORA ", " FOR A "},
        {" FORIEGN ", " FOREIGN "},
        {" FORTHE ", " FOR THE "},
        {" FORWRD ", " FORWARD "},
        {" FORWRDS ", " FOWARDS "},
        {" FOUDN ", " FOUND "},
        {" FOWARD ", " FORWARD "},
        {" FOWARDS ", " FORWARD "},
        {" FREIND ", " FRIEND "},
        {" FREINDLY ", " FRIENDLY "},
        {" FREINDS ", " FRIENDS "},
        {" FRMO ", " FROM "},
        {" FROMT HE ", " FROM THE "},
        {" FROMTHE ", " FROM THE "},
        {" FURNERAL ", " FUNERAL "},
        {" FWE ", " FEW "},
        {" GARANTEE ", " GUARANTEE "},
        {" GAURD ", " GUARD "},
        {" GEMERAL ", " GENERAL "},
        {" GERAT ", " GREAT "},
        {" GETING ", " GETTING "},
        {" GETTIN ", " GETTING "},
        {" GIEVN ", " GIVEN "},
        {" GIVEING ", " GIVING "},
        {" GLOABL ", " GLOBAL "},
        {" GOIGN ", " GOING "},
        {" GONIG ", " GOING "},
        {" GOVENMENT ", " GOVERNMENT "},
        {" GOVERMENT ", "GOVERNMENT "},
        {" GRUOP ", " GROUP "},
        {" GRUOPS ", " GROUPS "},
        {" GRWO ", " GROW "},
        {" GUIDLINES ", " GUIDELINES "},
        {" HADBEEN ", " HAD BEEN "},
        {" HADN;T ", " HADN'T "},
        {" HAEV ", " HAVE "},
        {" HAPEN ", " HAPPEN "},
        {" HAPENED ", " HAPPENED "},
        {" HAPENING ", " HAPPENING "},
        {" HAPENS ", " HAPPENS "},
        {" HAPPEND ", " HAPPENED "},
        {" HASBEEN ", " HAS BEEN "},
        {" HASN;T ", " HASN'T "},
        {" HASNT ", " HASN'T "},
        {" HAVEBEEN ", " HAVE BEEN "},
        {" HAVEING ", " HAVING "},
        {" HAVEN;T ", " HAVEN'T "},
        {" HDA ", " HAD "},
        {" HE;LL ", " HE'LL "},
        {" HEARIGN ", " HEARING "},
        {" HELPFULL ", " HELPFUL "},
        {" HERAT ", " HEART "},
        {" HERE;S ", " HERE'S "},
        {" HESAID ", " HE SAID "},
        {" HEWAS ", " HE WAS "},
        {" HISMELF ", " HIMSELF "},
        {" HLEP ", " HELP "},
        {" HSA ", " HAS "},
        {" HSI ", " HIS "},
        {" HTE ", " THE "},
        {" HTERE ", " THERE "},
        {" HTESE ", " THESE "},
        {" HTEY ", " THEY "},
        {" HTING ", " THING "},
        {" HTINK ", " THINK "},
        {" HTIS ", " THIS "},
        {" HTP: ", " HTTP: "},
        {" HTTP ", " HTTP:// "},
        {" HTTPL ", " HTTP: "},
        {" HVAE ", " HAVE "},
        {" HVAING ", " HAVING "},
        {" HWICH ", " WHICH "},
        {" I SNOT ", " IS NOT "},
        {" I;D ", " I'D "},
        {" I;LL ", " I'LL "},
        {" IDAE  ", " IDEA "},
        {" IDAES ", " IDEAS "},
        {" IDENTOFY ", " IDENTIFY "},
        {" IHS ", " HIS "},
        {" IITS THE ", " IT'S THE "},
        {" IM ", " I'M "},
        {" IMEDIATE ", " IMMEDIATE "},
        {" IMEDIATLY ", " IMMEDIATELY "},
        {" IMMEDIATLY ", " IMMEDIATELY "},
        {" IMPORTENT ", " IMPORTANT "},
        {" IMPORTNAT ", " IMPORTANT "},
        {" IMPOSSABLE ", " IMPOSSIBLE "},
        {" IMPROVEMNT ", " IMPROVEMENT "},
        {" IMPROVMENT ", " IMPROVEMENT "},
        {" INCLUD ", " INCLUDE "},
        {" INDECATE ", " INDICATE "},
        {" INDENPENDENCE ", " INDEPENDENCE "},
        {" INDENPENDENT ", " INDEPENDENT "},
        {" INDEPEDENT ", " INDEPENDENT "},
        {" INDEPENDANCE ", " INDEPENDENCE "},
        {" INDEPENDANT ", " INDEPENDENT "},
        {" INFLUANCE ", " INFLUENCE "},
        {" INFOMATION ", " INFORMATION "},
        {" INFORMATOIN ", " INFORMATION "},
        {" INITAL ", " INITIAL "},
        {" INSTALELD ", " INSTALLED "},
        {" INSTED ", " INSTEAD "},
        {" INSURENCE ", " INSURANCE "},
        {" INT HE ", " IN THE "},
        {" INTEH ", " IN THE "},
        {" INTERUM ", " INTERIM "},
        {" INTHE ", " IN THE "},
        {" INWHICH ", " IN WHICH "},
        {" ISN;T ", " ISN'T "},
        {" ISTHE ", " IS THE "},
        {" IT SNOT ", " IT'S NOT "},
        {" IT;LL ", " IT'LL "},
        {" IT;S ", " IT'S "},
        {" IT' SNOT ", " IT'S NOT "},
        {" ITIS ", " IT IS "},
        {" ITITIAL ", " INITIAL "},
        {" ITNEREST ", " INTEREST "},
        {" ITNERESTED ", " INTERESTED "},
        {" ITNERESTING ", " INTERESTING "},
        {" ITNERESTS ", " INTERESTS "},
        {" ITS A ", " IT'S A "},
        {" ITS THE ", " IT'S THE "},
        {" ITWAS ", " IT WAS "},
        {" IWLL ", " WILL "},
        {" IWTH ", " WITH "},
        {" JSUT ", " JUST "},
        {" JUGMENT ", " JUDGEMENT "},
        {" KNOWLDGE ", " KNOWLEDGE "},
        {" KNOWLEGE ", " KNOWLEDGE "},
        {" KNWO ", " KNOW "},
        {" KNWON ", " KNOWN "},
        {" KNWOS ", " KNOWS "},
        {" KONW ", " KNOW "},
        {" KONWN ", " KNOWN "},
        {" KONWS ", " KNOWS "},
        {" LABRATORY ", " LABORATORY "},
        {" LASTYEAR ", " LAST YEAR "},
        {" LEARNIGN ", " LEARNING "},
        {" LENGHT ", " LENGTH "},
        {" LET;S ", " LET'S "},
        {" LET'S HIM ", " LETS HIM "},
        {" LET'S IT ", " LETS IT "},
        {" LEVLE ", " LEVEL "},
        {" LIBARY ", " LIBRARY "},
        {" LIBRARRY ", " LIBRARY "},
        {" LIBRERY ", " LIBRARY "},
        {" LIEK ", " LIKE "},
        {" LIEKD ", " LIKED "},
        {" LIEUTENENT ", " LIEUTENANT "},
        {" LIEV ", " LIVE "},
        {" LIKLY ", " LIKELY "},
        {" LISENCE ", " LICENSE "},
        {" LITTEL ", " LITTLE "},
        {" LITTTLE ", " LITTLE "},
        {" LIUKE ", " LIKE "},
        {" LIVEING ", " LIVING "},
        {" LOEV ", " LOVE "},
        {" LONLY ", " LONELY "},
        {" LOOKIGN ", " LOOKING "},
        {" MAITENENCE ", " MAITENANCE "},
        {" MAKEING ", " MAKING "},
        {" MANAGMENT ", " MANAGEMENT "},
        {" MANTAIN ", " MAINTAIN "},
        {" MARRAIGE ", " MARRIAGE "},
        {" MAY OF BEEN ", " MAY HAVE BEEN "},
        {" MAY OF HAD ", " MAY HAVE HAD "},
        {" MEMEBER ", " MEMBER "},
        {" MERCHENT ", " MERCHANT "},
        {" MESAGE ", " MESSAGE "},
        {" MESAGES ", " MESSAGES "},
        {" MIGHT OF BEEN ", " MIGHT HAVE BEEN "},
        {" MIGHT OF HAD ", " MIGHT HAVE HAD "},
        {" MISPELL ", " MISSPELL "},
        {" MISPELLING ", " MISSPELLING "},
        {" MISPELLINGS ", " MISSPELLINGS "},
        {" MKAE ", " MAKE "},
        {" MKAES ", " MAKES "},
        {" MKAING ", " MAKING "},
        {" MOENY ", " MONEY "},
        {" MORGAGE ", " MORTGAGE "},
        {" MROE ", " MORE "},
        {" MUST OF BEEN ", " MUST HAVE BEEN "},
        {" MUST OF HAD ", " MUST HAVE HAD "},
        {" MYSEFL ", " MYSELF "},
        {" MYU ", " MY "},
        {" NECASSARILY ", " NECESSARILY "},
        {" NECASSARY ", " NECESSARY "},
        {" NECCESSARILY ", " NECESSARILY "},
        {" NECCESSARY ", " NECESSARY "},
        {" NECESARILY ", " NECESSARILY "},
        {" NECESARY ", " NECESSARY "},
        {" NEGOTIAING ", " NEGOTIATING "},
        {" NKOW ", " KNOW "},
        {" NOTHIGN ", " NOTHING "},
        {" NVER ", " NEVER "},
        {" NWE ", " NEW "},
        {" NWO ", " NOW "},
        {" OBEDIANT ", " OBEDIENT "},
        {" OCASION ", " OCCASION "},
        {" OCCASSION ", " OCCASION "},
        {" OCCURED ", " OCCURRED "},
        {" OCCURENCE ", " OCCURRENCE "},
        {" OCCURRANCE ", " OCCURRENCE "},
        {" OCUR ", " OCCUR "},
        {" OEPRATOR ", " OPERATOR "},
        {" OFITS ", " OF ITS "},
        {" OFT HE ", " OF THE "},
        {" OFTHE ", " OF THE "},
        {" OGING ", " GOING "},
        {" OHTER ", " OTHER "},
        {" OMRE ", " MORE "},
        {" ONEOF ", " ONE OF "},
        {" ONEPOINT ", " ONE POINT "},
        {" ONT HE ", " ON THE "},
        {" ONTHE ", " ON THE "},
        {" ONYL ", " ONLY "},
        {" OPPASITE ", " OPPOSITE "},
        {" OPPERATION ", " OPERATION "},
        {" OPPERTUNITY ", " OPPORTUNITY "},
        {" OPPOSATE ", " OPPOSITE "},
        {" OPPOSIBLE ", " OPPOSABLE "},
        {" OPPOSIT ", " OPPOSITE "},
        {" OPPOTUNITIES ", " OPPORTUNITIES "},
        {" OPPOTUNITY ", " OPPORTUNITY "},
        {" ORGINIZATION ", " ORGANIZATION "},
        {" ORGINIZED ", " ORGANIZED "},
        {" OTEHR ", " OTHER "},
        {" OTU ", " OUT "},
        {" OUTOF ", " OUT OF "},
        {" OVERTHE ", " OVER THE "},
        {" OWKR ", " WORK "},
        {" OWULD ", " WOULD "},
        {" OXIDENT ", " OXIDANT "},
        {" PAPAER ", " PAPER "},
        {" PARLIMENT ", " PARLIAMENT "},
        {" PARTOF ", " PART OF "},
        {" PAYMETN ", " PAYMENT "},
        {" PAYMETNS ", " PAYMENTS "},
        {" PCITURE ", " PICTURE "},
        {" PEICE ", " PIECE "},
        {" PEICES ", " PIECES "},
        {" PEOLPE ", " PEOPLE "},
        {" PEOPEL ", " PEOPLE "},
        {" PERCENTOF ", " PERCENT OF "},
        {" PERCENTTO ", " PERCENT TO "},
        {" PERFORMENCE ", " PERFORMANCE "},
        {" PERHASP ", " PERHAPS "},
        {" PERHPAS ", " PERHAPS "},
        {" PERMANANT ", " PERMANENT "},
        {" PERMINENT ", " PERMANENT "},
        {" PERSONALYL ", " PERSONALLY "},
        {" PLEASENT ", " PLEASANT "},
        {" POEPLE ", " PEOPLE "},
        {" PORBLEM ", " PROBLEM "},
        {" PORBLEMS ", " PROBLEMS "},
        {" PORVIDE ", " PROVIDE "},
        {" POSSABLE ", " POSSIBLE "},
        {" POSTITION ", " POSITION "},
        {" POTENTIALY ", " POTENTIALLY "},
        {" PREGNENT ", " PREGNANT "},
        {" PRESANCE ", " PRESENCE "},
        {" PROBELM ", " PROBLEM "},
        {" PROBELMS ", " PROBLEMS "},
        {" PROMINANT ", " PROMINENT "},
        {" PSOITION ", " POSITION "},
        {" PTOGRESS ", " PROGRESS "},
        {" PUTING ", " PUTTING "},
        {" PWOER ", " POWER "},
        {" QUATER ", " QUARTER "},
        {" QUATERS ", " QUARTERS "},
        {" QUESION ", " QUESTION "},
        {" QUESIONS ", " QUESTIONS "},
        {" QUESTIOMS ", " QUESTIONS "},
        {" QUESTIOSN ", " QUESTIONS "},
        {" QUESTOIN ", " QUESTION "},
        {" QUETION ", " QUESTION "},
        {" QUETIONS ", " QUESTIONS "},
        {" REALYL ", " REALLY "},
        {" RECCOMEND ", " RECOMMEND "},
        {" RECCOMMEND ", " RECOMMEND "},
        {" RECEIEVE ", " RECEIVE "},
        {" RECIEVE ", "  RECEIVE "},
        {" RECIEVED ", " RECEIVED "},
        {" RECIEVING ", " RECEIVING "},
        {" RECOMEND ", " RECOMMEND "},
        {" RECOMENDATION ", " RECOMMENDATION "},
        {" RECOMENDATIONS ", " RECOMMENDATIONS "},
        {" RECOMENDED ", " RECOMMENDED "},
        {" RECONIZE ", " RECOGNIZE "},
        {" RECROD ", " RECORD "},
        {" RELIGOUS ", " RELIGIOUS "},
        {" RELUCTENT ", " RELUCTANT "},
        {" REMEBER ", " REMEMBER "},
        {" REOMMEND ", " RECOMMEND "},
        {" REPRESENTATIVS ", " REPRESENTATIVES "},
        {" REPRESENTIVES ", " REPRESENTATIVES "},
        {" REPRESETNED ", " REPRESENTED "},
        {" REPRESNT ", " REPRESENT "},
        {" RESERACH ", " RESEARCH "},
        {" RESOLLUTION ", " RESOLUTION "},
        {" RESORCES ", " RESOURCES "},
        {" RESPOMD ", " RESPOND "},
        {" RESPOMSE ", " RESPONSE "},
        {" RESPONCE ", " RESPONSE "},
        {" RESPONSABILITY ", " RESPONSIBILITY "},
        {" RESPONSABLE ", " RESPONSIBLE "},
        {" RESPONSIBILE ", " RESPONSIBLE "},
        {" RESPONSIBLITY ", " RESPONSIBILIY "},
        {" RESTARAUNT ", " RESTAURANT "},
        {" RESTUARANT ", " RESTAURANT "},
        {" REULT ", " RESULT "},
        {" REVEIW ", " REVIEW "},
        {" REVEIWING ", " REVIEWING "},
        {" RUMERS ", " RUMORS "},
        {" RWITE ", " WRITE "},
        {" RYTHM ", " RHYTHM "},
        {" SAIDHE ", " SAID HE "},
        {" SAIDIT ", " SAID IT "},
        {" SAIDT HE ", " SAID THE "},
        {" SAIDTHAT ", " SAID THAT "},
        {" SAIDTHE ", " SAID THE "},
        {" SCEDULE ", " SCHEDULE "},
        {" SCEDULED ", " SCHEDULED "},
        {" SECRATARY ", " SECRETARY "},
        {" SECTINO ", " SECTION "},
        {" SEH ", " SHE "},
        {" SELECTOIN ", " SELECTION "},
        {" SENTANCE ", " SENTENCE "},
        {" SEPAREATE ", " SEPARATE "},
        {" SEPERATE ", " SEPARATE "},
        {" SERCUMSTANCES ", " CIRCUMSTANCES "},
        {" SHCOOL ", " SCHOOL "},
        {" SHE;LL ", " SHE'LL "},
        {" SHESAID ", " SHE SAID "},
        {" SHINEING ", " SHINING "},
        {" SHIPED ", " SHIPPED "},
        {" SHOUDL ", " SHOULD "},
        {" SHOUDLN'T ", " SHOULDN'T "},
        {" SHOULD OF BEEN ", " SHOULD HAVE BEEN "},
        {" SHOULD OF HAD ", " SHOULD HAVE HAD "},
        {" SHOULDENT ", " SHOULDN'T "},
        {" SHOULDN;T ", " SHOULDN'T "},
        {" SHOULDNT ", " SHOULDN'T "},
        {" SHOWINF ", " SHOWING "},
        {" SIGNIFACNT ", " SIGNIFICANT "},
        {" SIMALAR ", " SIMILAR "},
        {" SIMILIAR ", " SIMILAR "},
        {" SIMPYL ", " SIMPLY "},
        {" SINCERLY ", " SINCERELY "},
        {" SITLL ", " STILL "},
        {" SMAE ", " SAME "},
        {" SMOE ", " SOME "},
        {" SOEM ", " SOME "},
        {" SOHW ", " SHOW "},
        {" SOICAL ", " SOCIAL "},
        {" SOMETHIGN ", " SOMETHING "},
        {" SOMETING ", " SOMETHING "},
        {" SOMEWAHT ", " SOMEWHAT "},
        {" SOMTHING ", " SOMETHING "},
        {" SOMTIMES ", " SOMETIMES "},
        {" SOT HAT ", " SO THAT "},
        {" SOUDN ", " SOUND "},
        {" SOUDNS ", " SOUNDS "},
        {" SPEACH ", " SPEECH "},
        {" SPECIFICALY ", " SPECIFICALLY "},
        {" SPECIFICALYL ", " SPECIFICALLY "},
        {" STATMENT ", " STATEMENT "},
        {" STATMENTS ", " STATEMENTS "},
        {" STNAD ", " STAND "},
        {" STOPRY ", " STORY "},
        {" STOYR ", " STORY "},
        {" STPO ", " STOP "},
        {" STRENTGH ", " STENGTH "},
        {" STROY ", " STORY "},
        {" STRUGGEL ", " STRUGGLE "},
        {" STRUGLE ", " STRUGGLE "},
        {" STUDNET ", " STUDENT "},
        {" SUCCESSFULL ", " SUCCESSFUL "},
        {" SUCCESSFULY ", " SUCCESSFULLY "},
        {" SUCCESSFULYL ", " SUCCESSFULLY "},
        {" SUCESS ", " SUCCESS "},
        {" SUCCESSFULL ", " SUCCESSFUL "},
        {" SUFFICIANT ", " SUFFICIENT "},
        {" SUPOSED ", " SUPPOSED "},
        {" SUPPOSSED ", " SUPPOSED "},
        {" SUPRISE ", " SURPRISE "},
        {" SUPRISED ", " SURPRISED "},
        {" SWIMING ", " SWIMMING "},
        {" TAHN ", " THAN "},
        {" TAHT ", " THAT "},
        {" TALEKD ", " TALKED "},
        {" TALIKGN ", " TALKING "},
        {" TATH ", " THAT "},
        {" TECNICAL ", " TECHNICAL "},
        {" TEH ", " THE "},
        {" TEHY ", " THEY "},
        {" TELLT HE ", " TELL THE "},
        {" TERMOIL ", " TURMOIL "},
        {" TGHE ", " THE "},
        {" TGHIS ", " THIS "},
        {" THANSK ", " THANKS "},
        {" THATS ", " THAT'S "},
        {" THATT HE ", " THAT THE "},
        {" THATTHE ", " THAT THE "},
        {" THECOMPANY ", " THE COMPANY "},
        {" THEFIRST ", " THE FIRST "},
        {" THEGOVERNMENT ", " THE GOVERNMENT "},
        {" THEIR ARE ", " THERE ARE "},
        {" THEIR IS ", " THERE IS "},
        {" THEMSELF ", " THEMSELVES "},
        {" THEMSELFS ", " THEMSELVES "},
        {" THENEW ", " THE NEW "},
        {" THERE'S IS ", " THEIRS IS "},
        {" THERI ", " THEIR "},
        {" THESAME ", " THE SAME "},
        {" THE TWO ", " THE TWO "},
        {" THEY;L ", " THEY'LL "},
        {" THEY;LL ", " THEY'LL "},
        {" THEY;R ", " THEY'RE "},
        {" THEY;RE ", " THEY'RE "},
        {" THEY;V ", " THEY'VE "},
        {" THEY;VE ", " THEY'VE "},
        {" THEY'RE ARE ", " THERE ARE "},
        {" THEY'RE IS ", " THERE IS "},
        {" THEYLL ", " THEY'LL "},
        {" THEYVE ", " THEY'VE "},
        {" THGAT ", " THAT "},
        {" THGE ", " THE "},
        {" THIER ", " THEIR "},
        {" THIGSN ", " THINGS "},
        {" THISYEAR ", " THIS YEAR "},
        {" THNA ", " THAN "},
        {" THNE ", " THEN "},
        {" THNIG ", " THING "},
        {" THNIGS ", " THINGS "},
        {" THREATEND ", " THREATENED "},
        {" THSI ", " THIS "},
        {" THSOE ", " THOSE "},
        {" THTA ", " THAT "},
        {" TIHS ", " THIS "},
        {" TIMNE ", " TIME "},
        {" TIOGETHER ", " TOGETHER "},
        {" TJE ", " THE "},
        {" TIHE ", " THE "},
        {" TKAE ", " TAKE "},
        {" TKAES ", " TAKES "},
        {" TKAING ", " TAKING "},
        {" TLAKING ", " TALKING "},
        {" TODYA ", " TODAY "},
        {" TOGEHTER ", " TOGETHER "},
        {" TOLDT HE ", " TOLD THE "},
        {" TOMOROW ", " TOMORROW "},
        {" TONGIHT ", " TONIGHT "},
        {" TONIHGT ", " TONIGHT "},
        {" TOT HE ", " TO THE "},
        {" TOTALY ", " TOTALLY "},
        {" TOTALYL ", " TOTALLY "},
        {" TOTHE ", " TO THE "},
        {" TOWRAD ", " TOWARD "},
        {" TRADITIONALYL ", " TRADITIONALLY "},
        {" TRANSFERED ", " TRANSFERRED "},
        {" TRUELY ", " TRULY "},
        {" TRULEY ", " TRULY "},
        {" TRYED ", " TRIED "},
        {" TTHE ", " THE "},
        {" TYHAT ", " THAT "},
        {" TYHE ", " THE "},
        {" UDNERSTAND ", " UNDERSTAND "},
        {" UNDERSTNAD ", " UNDERSTAND "},
        {" UNDERT HE ", " UNDER THE "},
        {" UNITEDSTATES ", " UNITED STATES "},
        {" UNLIEK ", " UNLIKE "},
        {" UNPLEASENTLY ", " UNPLEASANTLY "},
        {" UNTILL ", " UNTIL "},
        {" USEING ", " USING "},
        {" USUALYL ", " USUALLY "},
        {" VEYR ", " VERY "},
        {" VIRTUALYL ", " VIRTUALLY "},
        {" VREY ", " VERY "},
        {" VULNERIBLE ", " VULNERABLE "},
        {" WA SNOT ", " WAS NOT "},
        {" WAHT ", " WHAT "},
        {" WARRENT ", " WARRANT "},
        {" WASNT ", " WASN'T "},
        {" WATN ", " WANT "},
        {" WE;D ", " WE'D "},
        {" WE;LL ", " WE'LL "},
        {" WE;RE ", " WE'RE "},
        {" WE;VE ", " WE'VE "},
        {" WEHN ", " WHEN "},
        {" WERN'T ", " WEREN'T "},
        {" WERRE ", " WERE "},
        {" WHAT;S ", " WHAT'S "},
        {" WHCIH ", " WHICH "},
        {" WHENT HE ", " WHEN THE "},
        {" WHERE;S ", " WHERE'S "},
        {" WHERRE ", " WHERE "},
        {" WHIC ", " WHICH "},
        {" WHICHT HE ", " WHICH THE "},
        {" WHIHC ", " WHICH "},
        {" WHO;S ", " WHO'S "},
        {" WHO;VE ", " WHO'VE "},
        {" WHTA ", " WHAT "},
        {" WIEF ", " WIFE "},
        {" WIERD ", " WEIRD "},
        {" WIHCH ", " WHICH "},
        {" WIHT ", " WITH "},
        {" WILL OF BEEN ", " WILL HAVE BEEN "},
        {" WILL OF HAD ", " WILL HAVE HAD "},
        {" WILLBE ", " WILL BE "},
        {" WINDOES ", " WINDOWS "},
        {" WITHA ", " WITH A "},
        {" WITHE ", " WITH "},
        {" WHITHT HE ", " WITH THE "},
        {" WITHTHE ", " WITH THE "},
        {" WIULL ", " WILL "},
        {" WNAT ", " WANT "},
        {" WNATED ", " WANTED "},
        {" WNATS ", " WANTS "},
        {" WO'NT ", " WON'T "},
        {" WOH ", " WHO "},
        {" WOHLE ", " WHOLE "},
        {" WOKR ", " WORK "},
        {" WON;T ", " WON'T "},
        {" WOUDL ", " WOULD "},
        {" WOUDLN'T ", " WOULDN'T "},
        {" WOULD OF BEEN ", " WOULD HAVE BEEN "},
        {" WOULD OF HAD ", " WOULD HAVE HAD "},
        {" WOULDBE ", " WOULD BE "},
        {" WOULDN;T ", " WOULDN'T "},
        {" WOULDNT ", " WOULDN'T "},
        {" WRIET ", " WRITE "},
        {" WRITTING ", " WRITING "},
        {" WROD ", " WORD "},
        {" WROET ", " WROTE "},
        {" WROKING ", " WORKING "},
        {" WTIH ", " WITH "},
        {" WUOULD ", " WOULD "},
        {" WYA ", " WAY "},
        {" YERA ", " YEAR "},
        {" YERAS ", " YEARS "},
        {" YERSA ", " YEARS "},
        {" YOIU ", " YOU "},
        {" YOU;D ", " YOU'D "},
        {" YOU;RE ", " YOU'RE "},
        {" YOU'RE OWN ", " YOUR OWN "},
        {" YOUARE ", " YOU ARE "},
        {" YOUR A ", " YOU'RE A "},
        {" YOUR AN ", " YOU'RE AN "},
        {" YOUR HER ", " YOU'RE HER "},
        {" YOUR HERE ", " YOU'RE HERE "},
        {" YOUR HIS ", " YOU'RE HIS "},
        {" YOUR MY ", " YOU'RE MY "},
        {" YOUR THE ", " YOU'RE THE "},
        {" YOUR THEIR ", " YOU'RE THEIR "},
        {" YOUR YOUR ", " YOU'RE YOUR "},
        {" YOUVE ", " YOU'VE "},
        {" YTOU ", " YOU "},
        {" YUO ", " YOU "},
        {" YUOR ", " YOUR "}
    }; 

    public static string clean (string text, Regex regex) {
        try{
            return regex.replace (text, text.length, 0, "");
        }catch(GLib.RegexError e){
            print(e.message);
            return text;
        }
    }

    public static string fix_typos (string text) {
        string fixed_text = text;
        foreach (Correction typo in typos) {
            fixed_text = typo.correct (text);
        }
        return fixed_text;
    }

    public static string replace (string key, string replacement, string text) {
        if (text.index_of (key) > -1) {
            return text.replace(key, replacement);
        }
        return text;
    }

    public static bool is_empty (string text) {
        return (text.strip() == "");
    }

    public static string capitalize (string text) {
        return "";        
    }

    public static string get_suffix (string text, string key) {
        string suffix = "";
        int position = text.index_of(key);
        if(position != -1){
            position += key.length;
            suffix = text.substring(position, text.length - position);
        }
        return suffix;
    }

    public static string get_prefix (string text, string key) {
        string prefix = "";
        int position = text.index_of(key);
        if(position != -1){
            prefix = text.substring(0, position);
        }
        return prefix;
    }
}
